SystemOrganization addCategory: #'Khami-Test-Core'!
SystemOrganization addCategory: #'Khami-Test-Core-Locations'!
SystemOrganization addCategory: #'Khami-Test-Core-Support'!
SystemOrganization addCategory: #'Khami-Test-Utilities'!
SystemOrganization addCategory: #'Khami-Test-Web'!

TestCase subclass: #KmDirectionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core-Locations'!

!KmDirectionTest methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 13:17'!
testOppositeBottom
	self assert: Top equals: Bottom opposite! !

!KmDirectionTest methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 13:17'!
testOppositeLeft
	self assert: Right equals: Left opposite! !

!KmDirectionTest methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 13:17'!
testOppositeRight
	self assert: Left equals: Right opposite! !

!KmDirectionTest methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 13:16'!
testOppositeTop
	self assert: Bottom equals: Top opposite! !

TestCase subclass: #KmGameTest
	instanceVariableNames: 'testGame gameWithNoValidMove gameWithValidMove gameWithMoveAvailableAfterRotation player1 player2'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmGameTest methodsFor: 'running' stamp: 'StuartHerring 5/10/2011 21:46'!
setUp
	super setUp.
	player1 := KmPlayer named: 'Player 1' withColour: Color blue.
	player2 := KmPlayer named: 'Player 2' withColour: Color red.
	testGame := KmGame testGame.
	gameWithNoValidMove := KmGame tileSet: (KmTileSet buildFromStrings: {'VFFFV----'. 'FFFFFFFFF'}).
	gameWithValidMove := KmGame tileSet: (KmTileSet buildFromStrings: {'FFFFFFFFF'. 'FFFFVFFFF'. 'FFFFVFFFF'}).
	gameWithMoveAvailableAfterRotation := KmGame tileSet: (KmTileSet buildFromStrings: {'VFFFV----'. 'VFFFVFFFF'}).! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/10/2011 21:47'!
testAddingAPlayerIncreasesThePlayerCount
	testGame addPlayer: player1.
	self assert: 1 equals: testGame players size.! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 21:57'!
testCallingValidMoveAvailableDoesntChangeRotation
	| game tileSegment |
	game := gameWithValidMove.
	game takeTile.
	tileSegment := game currentTile at: Top.
	game validMoveAvailable.
	self assert: tileSegment equals: (game currentTile at: Top).! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 22:26'!
testCantPlaceTileInInvalidLocation
	| game |
	game := gameWithNoValidMove.
	game takeTile.
	self should: [ game placeCurrentTileAtRow: 1 andColumn: 1] raise: KmInvalidMove
! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/10/2011 21:50'!
testCurrentPlayerIsSetByNextPlayer
	testGame addPlayer: player1.
	testGame nextPlayer.
	self assert: player1 equals: testGame currentPlayer.  ! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:14'!
testCurrentTileStartsBlank
	 | game |
	game := testGame.
	self assert: nil equals: game currentTile.! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 21:58'!
testDiscardTile
	| game |
	game := gameWithNoValidMove.
	game takeTile.
	game discardTile.
	self assert: nil equals: game currentTile! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 21:58'!
testDiscardTileOnlyAllowedWhenNoValidMoveAvailable
	| game |
	game := gameWithValidMove.
	game takeTile.
	self should: [ game discardTile] raise: KmInvalidGameState.! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 22:41'!
testGameIsComplete
	| game |
	game := gameWithValidMove.
	game takeTile.
	game placeCurrentTileAtRow: 2 andColumn: 1.
	game takeTile.
	game placeCurrentTileAtRow: 2 andColumn: 1.
	self assert: game isComplete! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 22:22'!
testGameIsNotComplete
	self deny: gameWithValidMove isComplete! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 20:49'!
testGameStartsWithNoPlayers
	self assert: 0 equals: testGame players size.! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/10/2011 21:47'!
testNextPlayerGetsFirstPlayerFirstTime
	testGame addPlayer: player1.
	self assert: player1 equals: testGame nextPlayer.  ! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/10/2011 21:49'!
testNextPlayerGetsSecondPlayerSecondTime
	testGame addPlayer: player1.  
	testGame addPlayer: player2.
	testGame nextPlayer.
	self assert: player2 equals: testGame nextPlayer.! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/10/2011 21:53'!
testNextPlayerLoopsAfterLastPlayer
	testGame addPlayer: player1.  
	testGame addPlayer: player2.
	testGame nextPlayer.
	testGame nextPlayer.
	self assert: player1 equals: testGame nextPlayer.! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 21:58'!
testNoValidMoveAvailable
	| game |
	game := gameWithNoValidMove.
	game takeTile.
	self deny: game validMoveAvailable.! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 22:35'!
testPlaceTile
	| game gameBoard tile | 
	game := gameWithValidMove.
	gameBoard := game board.
	tile := game takeTile.
	game placeCurrentTileAtRow: 1 andColumn: 2.
	self assert: tile equals: (gameBoard at: 2 at: 2)! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 22:36'!
testPlaceTileClearsCurrentTile
	| game |
	game := gameWithValidMove.
	game takeTile.
	game placeCurrentTileAtRow: 1 andColumn: 2.
	self assert: nil equals: testGame currentTile! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/10/2011 21:27'!
testPlaceTileSetsLastTile
	| game gameBoard tile | 
	game := gameWithValidMove.
	gameBoard := game board.
	tile := game takeTile.
	game placeCurrentTileAtRow: 1 andColumn: 2.
	self assert: tile equals: game lastTile! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 22:38'!
testPlaceTileWontReplaceExistingTile
	| game gameBoard | 
	game := gameWithValidMove.
	gameBoard := game board.
	game takeTile.
	game placeCurrentTileAtRow: 1 andColumn: 2.
	game takeTile.
	self should: [game placeCurrentTileAtRow: 2 andColumn: 2] raise: KmInvalidMove.
! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:14'!
testTakeTileSetsCurrentTile
	| game tile |
	game := testGame.
	tile := game takeTile.
	self assert: tile equals: game currentTile.! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:14'!
testTakeTileTwiceDoesntTakeAdditionalTile
	| game tile |
	game := testGame.
	tile := game takeTile.
	self assert: tile equals: game takeTile! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 21:58'!
testValidMoveAvailable
	| game |
	game := gameWithValidMove.
	game takeTile.
	self assert: game validMoveAvailable.! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 21:58'!
testValidMoveAvailableAfterRotation
	| game |
	game := gameWithMoveAvailableAfterRotation.
	game takeTile.
	self assert: game validMoveAvailable.! !

TestCase subclass: #KmHutScoringTest
	instanceVariableNames: 'player1 game hutSegment'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmHutScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/12/2011 07:19'!
setUp
	| tiles |
	super setUp.
	player1 := KmPlayer named: 'Player 1' withColour: Color blue.
	tiles := { 
		KmTile buildFromString: 'FFFFFFFF+'.
		KmTile buildFromString: 'FFFFFFFFF'.
		KmTile buildFromString: 'FFFFFFFFF'.
		KmTile buildFromString: 'FFFFFFFFF'.
		KmTile buildFromString: 'FFFFFFFFF'.
		KmTile buildFromString: 'FFFFFFFFF'.
		KmTile buildFromString: 'FFFFFFFFF'.
		KmTile buildFromString: 'FFFFFFFFF'.
		KmTile buildFromString: 'FFFFFFFFF'.
		KmTile buildFromString: 'FFFFFFFFF'.
		}.		
	game := KmGame tileSet: (KmTestingTileset buildFromTiles: tiles).
	game addPlayer: player1.
	game takeTile; placeCurrentTileAtRow: 1 andColumn: 2.
	game takeTile; placeCurrentTileAtRow: 2 andColumn: 1.
	game takeTile; placeCurrentTileAtRow: 2 andColumn: 4.
	game takeTile; placeCurrentTileAtRow: 3 andColumn: 2.
	game takeTile; placeCurrentTileAtRow: 3 andColumn: 4.
	game takeTile; placeCurrentTileAtRow: 4 andColumn: 2.	
	game takeTile; placeCurrentTileAtRow: 4 andColumn: 3.	
	hutSegment := (tiles at: 1) at: Centre.! !

!KmHutScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/14/2011 20:44'!
testCompleteHutReturnsPiece
	hutSegment piece: player1 takePiece.
	game takeTile; placeCurrentTileAtRow: 4 andColumn:  4.
	game calculateScore.
	self assert: 5 equals: player1 pieces size.! !

!KmHutScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/14/2011 21:53'!
testCompleteHutScoresNine
	hutSegment piece: player1 takePiece.
	game takeTile; placeCurrentTileAtRow: 4 andColumn:  4.
	game calculateScore.
	self assert: 9 equals: player1 score! !

!KmHutScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/14/2011 21:54'!
testFinalIncompleteHutScoresOnePerTile
	hutSegment piece: player1 takePiece.
	game calculateFinalScore.
	self assert: 8 equals: player1 score! !

!KmHutScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/12/2011 11:26'!
testHutOnItsOwnScores1
 	| s |
	s := KmHutTerritory newSegment.
	s piece: player1 takePiece.
	s territory calculateFinalScore.
	self assert: 1 equals: player1 score.! !

!KmHutScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/12/2011 07:17'!
testIncompleteHutDoesntReturnPiece
	hutSegment piece: player1 takePiece.
	game calculateScore.
	self assert: 4 equals: player1 pieces size.! !

!KmHutScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/12/2011 07:16'!
testIncompleteHutScoresNothing
	hutSegment piece: player1 takePiece.
	game calculateScore.
	self assert: 0 equals: player1 score.! !

!KmHutScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/14/2011 22:00'!
testScoringOnlyHappensOnce
	hutSegment piece: player1 takePiece.
	game takeTile; placeCurrentTileAtRow: 4 andColumn:  4.
	game calculateScore.
	game calculateScore.
	self assert: 9 equals: player1 score.! !

TestCase subclass: #KmHutTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmHutTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/14/2011 21:49'!
testAddSurroundingTileDoesNothingIfNoHut
	(KmTile buildFromString: 'FFFFFFFFF') addSurroundingTile.	! !

!KmHutTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/14/2011 21:48'!
testAddSurroundingTileInTileAddsToHutTerritory
	| t h |
	t := KmTile buildFromString: 'FFFFFFFF+'.
	h := (t at: Centre) territory.
	t addSurroundingTile.
	self assert: 1 equals: h surroundingTiles 
	! !

!KmHutTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/14/2011 20:54'!
testCantHaveMoreThan8SurroundingTiles
	| h| 
	h := KmHutTerritory new.
	8 timesRepeat: [h addSurroundingTile].
	self should: [ h addSurroundingTile ] raise: KmInvalidGameState! !

!KmHutTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/14/2011 20:49'!
testHutIsIncomplete
	self deny: KmHutTerritory new isComplete.! !

!KmHutTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/14/2011 20:51'!
testHutWith8SurroundingTilesIsComplete
	| h |
	h := KmHutTerritory new.
	8 timesRepeat: [h addSurroundingTile].
	self assert: h isComplete! !

!KmHutTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/14/2011 21:51'!
testPlacingHutNextToTileIncrementsTileCount
	| tiles game h |
	tiles := { KmTile buildFromString: 'FFFFFFFFF'. KmTile buildFromString: 'FFFFFFFF+'}.
	game := KmGame tileSet: (KmTestingTileset buildFromTiles: tiles).
	h := (tiles at: 2) at: Centre.
	game takeTile; placeCurrentTileAtRow: 1 andColumn: 2.
	self assert: 1 equals: h territory surroundingTiles! !

!KmHutTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/14/2011 20:59'!
testPlacingTileNextToHutIncrementsTileCount
	| tiles game h |
	tiles := { KmTile buildFromString: 'FFFFFFFF+'. KmTile buildFromString: 'FFFFFFFFF'}.
	game := KmGame tileSet: (KmTestingTileset buildFromTiles: tiles).
	h := (tiles at: 1) at: Centre.
	game takeTile; placeCurrentTileAtRow: 1 andColumn: 2.
	self assert: 1 equals: h territory surroundingTiles! !

TestCase subclass: #KmPieceTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmPieceTest methodsFor: 'tests' stamp: 'StuartHerring 5/10/2011 22:22'!
testPieceColourIsPlayerColour
	self assert: Color blue 
		equals: (KmPiece forPlayer: (KmPlayer named: 'Player 1' withColour: Color blue)) colour! !

!KmPieceTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 21:24'!
testPiecePlayer
	| p |
	p := KmPlayer new.
	self assert: p equals: (KmPiece forPlayer: p) player! !

TestCase subclass: #KmPlayerTest
	instanceVariableNames: 'player'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmPlayerTest methodsFor: 'fixtures' stamp: 'StuartHerring 5/9/2011 20:14'!
playerColour
	^Color blue! !

!KmPlayerTest methodsFor: 'fixtures' stamp: 'StuartHerring 5/9/2011 20:14'!
playerName
	^'Player 1'! !

!KmPlayerTest methodsFor: 'running' stamp: 'StuartHerring 5/9/2011 20:14'!
setUp
	player := KmPlayer named: self playerName withColour: self playerColour.! !

!KmPlayerTest methodsFor: 'fixtures' stamp: 'StuartHerring 5/9/2011 20:14'!
startingPieces
	^5! !

!KmPlayerTest methodsFor: 'fixtures' stamp: 'StuartHerring 5/12/2011 11:03'!
testAddScore
	player addScore: 5.
	self assert: 5 equals: player score.! !

!KmPlayerTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 21:11'!
testCantReturnPieceBelongingToAnotherPlayer
	| player2 |
	player2 := KmPlayer named: 'Player 2' withColour: Color red.
	self should: [ player returnPiece: player2 takePiece ] raise: Error
! !

!KmPlayerTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 20:18'!
testPieceTakenFromPlayerBelongsToPlayer
	self assert: player equals: player takePiece player! !

!KmPlayerTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 20:17'!
testPlayerColour
	self assert: self playerColour equals: player colour! !

!KmPlayerTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 20:14'!
testPlayerName
	self assert: self playerName equals: player name! !

!KmPlayerTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 20:15'!
testPlayerStartingPieceCount
	self assert: self startingPieces equals: player pieces size.! !

!KmPlayerTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 20:27'!
testReturnPieceIncreasesCount
	| p |
	p := player takePiece.
	player returnPiece: p.
	self assert: self startingPieces equals: player pieces size.! !

!KmPlayerTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 07:38'!
testStartingScore
	self assert: 0 equals: player score.! !

!KmPlayerTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 20:17'!
testTakePieceDeductsItFromPlayersPieces
	player takePiece.
	self assert: (self startingPieces - 1) equals: player pieces size.! !

TestCase subclass: #KmScoringTest
	instanceVariableNames: 'player1 completedRoad uncompletedRoad completedVillage uncompletedVillage farmWithCompletedVillage farmWithOnlyUncompletedVillage farmWithNoVillages game tile'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/14/2011 18:11'!
setUp
	| tiles |
	super setUp.
	player1 := KmPlayer named: 'Player 1' withColour: Color blue.
	tiles := { 
		KmTile buildFromString: 'VFVFVFVFF'.
		KmTile buildFromString: 'VFFFV---.F---'.
		KmTile buildFromString: 'FFVVFFVVF'.
		KmTile buildFromString: 'FFFFFFF--'.
		}.
	game := KmGame tileSet: (KmTestingTileset buildFromTiles: tiles).
	game takeTile; placeCurrentTileAtRow: 3 andColumn: 2. 
	game takeTile; placeCurrentTileAtRow: 1 andColumn: 2.  
	game takeTile; placeCurrentTileAtRow: 4 andColumn: 3.  
	tile := tiles at: 2.
	completedRoad := (tiles at: 2) at: Right.
	uncompletedRoad := (tiles at: 2) at: Left.
	completedVillage := (tiles at: 1) at: Bottom.
	uncompletedVillage := (tiles at: 1) at: Top.
	farmWithCompletedVillage := (tiles at: 1) at: Centre.
	farmWithOnlyUncompletedVillage := (tiles at: 3) at: Centre.
	farmWithNoVillages := (tiles at: 2) at: BottomLeft! !

!KmScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/12/2011 07:36'!
testCalculateFinalScoreOnGameCalculatesScoreOnAllTerritories
	| r v | 
	r := completedRoad territory.
	v := completedVillage territory.
	completedRoad piece: player1 takePiece.
	completedVillage piece: player1 takePiece.
	farmWithCompletedVillage piece: player1 takePiece.
	game calculateFinalScore.
	self assert: v tiles size + r tiles size + 4
		 equals: player1 score! !

!KmScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/12/2011 07:21'!
testCalculateScoreOnGameCalculatesScoreOnLastPlacedTile
	| t| 
	t := completedRoad territory.
	completedRoad piece: player1 takePiece.
	game calculateScore.
	self assert: 2 * t tiles size
		 equals: player1 score! !

!KmScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/11/2011 23:51'!
testCompleteRoadScoresTwoPerTile
	| t| 
	t := completedRoad territory.
	completedRoad piece: player1 takePiece.
	t calculateScore.
	self assert: 2 * t tiles size
		 equals: player1 score! !

!KmScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/11/2011 23:52'!
testCompleteVillageScoresTwoPerTile
	| t| 
	t := completedVillage territory.
	completedVillage piece: player1 takePiece.
	t calculateScore.
	self assert: 2 * t tiles size
		 equals: player1 score! !

!KmScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/14/2011 17:56'!
testFinalFarmWithCompletedVillageScoresFourPerVillage
	| t| 
	t := farmWithCompletedVillage territory.
	farmWithCompletedVillage piece: player1 takePiece.
	t calculateFinalScore.
	self assert: 4
		 equals: player1 score! !

!KmScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/14/2011 18:04'!
testFinalFarmWithNoVillageScoresNothing
	| t| 
	t := farmWithNoVillages territory.
	farmWithNoVillages piece: player1 takePiece.
	t calculateFinalScore.
	self assert: 0
		 equals: player1 score! !

!KmScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/12/2011 07:31'!
testFinalFarmWithOnlyUncompletedVillageScoresNothing
	| t| 
	t := farmWithOnlyUncompletedVillage territory.
	farmWithOnlyUncompletedVillage piece: player1 takePiece.
	t calculateFinalScore.
	self assert: 0
		 equals: player1 score! !

!KmScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/12/2011 07:07'!
testFinalIncompleteRoadScoresOnePerTile
	| t| 
	t := completedRoad territory.
	completedRoad piece: player1 takePiece.
	t calculateFinalScore.
	self assert: t tiles size
		 equals: player1 score! !

!KmScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/12/2011 07:07'!
testFinalIncompleteVillageScoresOnePerTile
	| t| 
	t := completedVillage territory.
	completedVillage piece: player1 takePiece.
	t calculateFinalScore.
	self assert: t tiles size
		 equals: player1 score! !

!KmScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/14/2011 18:06'!
testFixtureFarmWithCompletedVillage
	self assert: (farmWithCompletedVillage isFarm 
		and: [farmWithCompletedVillage territory adjacentTerritories anySatisfy: [ :t | t isVillage and: [t isComplete ]]])! !

!KmScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/14/2011 18:07'!
testFixtureFarmWithNoVillages
	self deny: (farmWithNoVillages isFarm not
		or: [farmWithNoVillages territory adjacentTerritories anySatisfy: [ :t | t isVillage ]] )! !

!KmScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/14/2011 18:08'!
testFixtureFarmWithOnlyUncompletedVillage
	self assert: (farmWithOnlyUncompletedVillage isFarm 
		and: [(farmWithOnlyUncompletedVillage territory adjacentTerritories select: [:t | t isVillage]) anySatisfy: [ :t | t isComplete not]])! !

!KmScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/11/2011 23:49'!
testIncompleteRoadScoresNothing
	uncompletedRoad piece: player1 takePiece.
	uncompletedRoad territory calculateScore.
	self assert: 0 equals: player1 score! !

!KmScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/11/2011 23:52'!
testIncompleteVillageScoresNothing
	uncompletedVillage piece: player1 takePiece.
	uncompletedVillage territory calculateScore.
	self assert: 0 equals: player1 score! !

!KmScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/11/2011 23:56'!
testScoringOnlyHappensOnce
	| t |
	t := completedRoad territory.
	completedRoad piece: player1 takePiece.
	t calculateScore.
	t calculateScore.
	self assert: 2 * t tiles size
		 equals: player1 score! !

!KmScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/11/2011 23:53'!
testSuccessfulScoringReturnsPiece
	completedRoad piece: player1 takePiece.
	completedRoad territory calculateScore.
	self assert: 5 equals: player1 pieces size! !

!KmScoringTest methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/11/2011 23:54'!
testUnsuccessfulScoringDoesntReturnPiece
	uncompletedRoad piece: player1 takePiece.
	uncompletedRoad territory calculateScore.
	self assert: 4 equals: player1 pieces size! !

TestCase subclass: #KmSegmentCreationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmSegmentCreationTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 22:52'!
testFarmFromCode
	self assert: (KmTileSegment fromChar: $F in: nil) isFarm! !

!KmSegmentCreationTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 22:51'!
testHutFromCode
	self assert: (KmTileSegment fromChar: $+ in: nil) isHut! !

!KmSegmentCreationTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:03'!
testNullSegmentIsNotAnything
	| s |
	s := KmNullTerritory newSegment.
	self deny: s isVillage.
	self deny: s isHut.
	self deny: s isFarm.
	self deny: s isRoad! !

!KmSegmentCreationTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 22:50'!
testRoadFromCode
	self assert: (KmTileSegment fromChar: $- in: nil) isRoad! !

!KmSegmentCreationTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 22:51'!
testVillageFromCode
	self assert: (KmTileSegment fromChar: $V in: nil) isVillage! !

!KmSegmentCreationTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 22:51'!
testWallFromCodeIsVillage
	self assert: (KmTileSegment fromChar: $W in: nil) isVillage! !

!KmSegmentCreationTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 22:52'!
testWallFromCodeIsWall
	self assert: (KmTileSegment fromChar: $W in: nil) isWall! !

!KmSegmentCreationTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 22:52'!
testWallFromCodeReallyHasVillageTerritory
	self assert: KmVillageTerritory equals: (KmTileSegment fromChar: $W in: nil) territory class! !

TestCase subclass: #KmSessionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Web'!

!KmSessionTest methodsFor: 'tests' stamp: 'StuartHerring 4/10/2011 22:13'!
testCurrentTileStartsAsNil
	| session |
	session := KmSession new.
	session game: KmGame testGame.
	self assert: session currentTile equals: nil! !

TestCase subclass: #KmTerritoryTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/14/2011 16:59'!
testAdjacentTerritoriesAcrossTilles
	|  t1 t2 |
	t1 := KmTile buildFromString: 'VFFFVFFFF'.
	t2 := KmTile buildFromString: 'FFFFF-F--F-F-'.
	t1 tileAt: Bottom put: t2.
	self assert: {
		(t1 at: Top) territory.
		(t2 at: Centre) territory} asSet 
	equals: (t2 at: Top) territory adjacentTerritories! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/14/2011 12:58'!
testAdjacentTerritoriesInSingleTile
	| t |
	t := KmTile buildFromString: 'VFFFV-F--F-F-'.
	self assert: {
		(t at: CentreTop) territory.
		(t at: Bottom ) territory} asSet
	equals: (t at: Centre) territory adjacentTerritories! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 21:50'!
testBlockerIsIncomplete
	self deny: KmNullTerritory new isComplete! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 4/22/2011 14:00'!
testCompleteVillage
	| tile1 tile2 |
	tile1 := KmTile buildFromString: 'VFFFVFFFF'.
	tile2 := KmTile buildFromString: 'FFVFFFVFF'.
	tile1 tileAt: Top put: tile2.
	self assert: (tile1 at: Top) territory isComplete.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 21:30'!
testFarmRegionFromCode
	self assert: (KmTileSegment fromChar: $F in: nil)  isFarm! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 22:59'!
testHutTerritoryCanHavePiece
	self assert: KmHutTerritory new canPlacePiece! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 19:13'!
testInitialTerritoryDoesNotHaveAPiece
	self deny: KmTerritory new hasPieces! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 19:13'!
testInitialTerritoryHasZeroPieces
	self assert: 0 equals: KmTerritory new pieces size.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 19:57'!
testIsComplete
	| tile1 tile2 |
	tile1 := KmTile buildFromString: 'FFFF-FFFF'.
	tile2 := KmTile buildFromString: 'FFFFFF-FF'.
	tile1 tileAt: Top put: tile2.
	self assert: (tile1 at: Top) territory isComplete.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:46'!
testLoopContentsIsComplete
	| tiles |
	tiles := {
		'FFFFFF---'. 'FFFFF--F-'. 'FFFF--FF-'. 'FFFF-FF--'.
	} collect: [ :s | KmTile buildFromString: s].
	
	(tiles at: 1) tileAt: Left put: (tiles at: 2).
	(tiles at: 2) tileAt: Bottom put: (tiles at: 3).
	(tiles at: 3) tileAt: Right put: (tiles at: 4).
	(tiles at: 4) tileAt: Top put: (tiles at: 1).
	
	self assert: ((tiles at: 1) at: LeftBottom) territory isComplete.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:47'!
testLoopContentsSegmentIsComplete
	| tiles |
	tiles := {
		'FFFFFF---'. 'FFFFF--F-'. 'FFFF--FF-'. 'FFFF-FF--'.
	} collect: [ :s | KmTile buildFromString: s].
	
	(tiles at: 1) tileAt: Left put: (tiles at: 2).
	(tiles at: 2) tileAt: Bottom put: (tiles at: 3).
	(tiles at: 3) tileAt: Right put: (tiles at: 4).
	(tiles at: 4) tileAt: Top put: (tiles at: 1).
	
	self assert: ((tiles at: 1) at: LeftBottom) isComplete.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:48'!
testLoopIsComplete
	| tiles |
	tiles := {
		'FFFFFF---'. 'FFFFF--F-'. 'FFFF--FF-'. 'FFFF-FF--'.
	} collect: [ :s | KmTile buildFromString: s].
	
	(tiles at: 1) tileAt: Left put: (tiles at: 2).
	(tiles at: 2) tileAt: Bottom put: (tiles at: 3).
	(tiles at: 3) tileAt: Right put: (tiles at: 4).
	(tiles at: 4) tileAt: Top put: (tiles at: 1).
	
	self assert: ((tiles at: 1) at: Left) territory isComplete.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:49'!
testLoopSegmentIsComplete
	| tiles |
	tiles := {
		'FFFFFF---'. 'FFFFF--F-'. 'FFFF--FF-'. 'FFFF-FF--'.
	} collect: [ :s | KmTile buildFromString: s].
	
	(tiles at: 1) tileAt: Left put: (tiles at: 2).
	(tiles at: 2) tileAt: Bottom put: (tiles at: 3).
	(tiles at: 3) tileAt: Right put: (tiles at: 4).
	(tiles at: 4) tileAt: Top put: (tiles at: 1).
	
	self assert: ((tiles at: 1) at: Left) isComplete.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:03'!
testMergeWith
	| s1 s2 |
	s1 := KmFarmTerritory newSegment.
	s2 := KmFarmTerritory newSegment.
	s1 territory mergeWith: s2 territory.
	self assert: s2 territory equals: s1 territory! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:03'!
testMergeWithAddsSegments
	| s1 s2 |
	s1 := KmFarmTerritory newSegment.
	s2 := KmFarmTerritory newSegment.
	s1 territory mergeWith: s2 territory.
	self assert: 2 equals: s1 territory size! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:03'!
testMergeWithRemovesAllSegments
	| s1 s2 territory |
	s1 := KmFarmTerritory newSegment.
	territory := s1 territory.
	s2 := KmFarmTerritory newSegment.
	s1 territory mergeWith: s2 territory.
	self assert: territory isEmpty! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 19:29'!
testMergingTerritoriesWithPiecesGivesSumOfPieces
	| s t |
	s := KmTileSegment fromChar: $F in: nil.
	s piece: KmPiece new.
	t := s territory.

	s := KmTileSegment fromChar: $F in: nil.
	s piece: KmPiece new.
	s territory mergeWith: t.  
	self assert: 2 equals: t pieces size.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 19:57'!
testNotComplete
	| tile1 tile2 |
	tile1 := KmTile buildFromString: 'FFFF-FFFF'.
	tile2 := KmTile buildFromString: 'FFFF-F-F-'.
	tile1 tileAt: Top put: tile2.
	self deny: (tile1 at: Top) territory isComplete.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/12/2011 10:55'!
testOnlyPlayerIsDominantPlayer
	| player segment  |
	player := KmPlayer named: 'Player 1' withColour: Color blue.
	segment := KmFarmTerritory newSegment
		piece: player takePiece;
		yourself.
	self assert: {player} asSet equals: segment territory dominantPlayers! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/12/2011 10:55'!
testPlayerWithMorePiecesIsDominant
	| p1 p2 s  |
	p1 := KmPlayer named: 'Player 1' withColour: Color blue.
	p2 := KmPlayer named: 'Player 2' withColour: Color red.
	s := KmFarmTerritory newSegment
		piece: p1 takePiece;
		yourself.
	s territory mergeWith: (KmFarmTerritory newSegment
			piece: p2 takePiece
			yourself) territory.
	s territory mergeWith: (KmFarmTerritory newSegment
			piece: p1 takePiece;
			yourself) territory.

	self assert:  {p1} asSet equals: s territory dominantPlayers! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/12/2011 10:56'!
testPlayersWithEqualPiecesAreBothDominant
	| p1 p2 s  |
	p1 := KmPlayer named: 'Player 1' withColour: Color blue.
	p2 := KmPlayer named: 'Player 2' withColour: Color red.
	s := KmFarmTerritory newSegment
		piece: p1 takePiece;
		yourself.
	s territory mergeWith: (KmFarmTerritory newSegment
		piece: p2 takePiece
		yourself) territory.

	self assert:  {p1. p2} asSet equals: s territory dominantPlayers! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/12/2011 10:57'!
testPlayersWithEquallyMorePiecesAreBothDominant
	| p1 p2 p3 s  |
	p1 := KmPlayer named: 'Player 1' withColour: Color blue.
	p2 := KmPlayer named: 'Player 2' withColour: Color red.
	p3 := KmPlayer named: 'Player 2' withColour: Color red.
	s := KmFarmTerritory newSegment
		piece: p1 takePiece;
		yourself.
	s territory mergeWith: (KmFarmTerritory newSegment
		piece: p1 takePiece
		yourself) territory.
	s territory mergeWith: (KmFarmTerritory newSegment
		piece: p2 takePiece
		yourself) territory.
	s territory mergeWith: (KmFarmTerritory newSegment
		piece: p2 takePiece
		yourself) territory.
	s territory mergeWith: (KmFarmTerritory newSegment
		piece: p3 takePiece
		yourself) territory.

	self assert:  {p1. p2} asSet equals: s territory dominantPlayers! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 19:12'!
testTerritoryWithSegmentContainingPieceHasExactlyOnePiece
	| s t |
	s := KmTileSegment fromChar: $F in: nil.
	t := s territory.
	s piece: KmPiece new.
	self assert: 1 equals: t pieces size.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 19:13'!
testTerritoryWithSegmentContainingPieceHasPieces
	| s t |
	s := KmTileSegment fromChar: $F in: nil.
	t := s territory.
	s piece: KmPiece new.
	self assert: t hasPieces! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:03'!
testTilesInSingleTile
	| tile |
	tile := KmTile blank.
	self assert: 1 equals: tile territories any tiles size.! !

TestCase subclass: #KmTestGameBoard
	instanceVariableNames: 'gameBoard'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmTestGameBoard methodsFor: 'running' stamp: 'StuartHerring 3/7/2011 21:19'!
setUp
	super setUp.
	gameBoard := KmGameBoard startingTile: KmTile startingTile.! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:20'!
testCanPlaceTile
	self assert: (gameBoard canPlaceTile: KmTile blank at: 3 at: 2) ! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:20'!
testCantPlaceTileBecauseAlreadyOccupied
	self deny: (gameBoard canPlaceTile: KmTile blank at: 2 at: 2) ! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:20'!
testCantPlaceTileBecauseDoesntConnect
	self deny: (gameBoard canPlaceTile: KmTile blank at: 1 at: 2) ! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:20'!
testCantPlaceTileBecauseNotAvailable
	self deny: (gameBoard canPlaceTile: KmTile blank at: 1 at: 1) ! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:18'!
testInitialColumnsIs3
	self assert: 3 equals: gameBoard columns.! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:18'!
testInitialRowsIs3
	self assert: 3 equals: gameBoard rows.! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:19'!
testPlaceTile
	 | tile |
	tile := KmTile blank.
	gameBoard at: 3 at: 2 put: tile.
	self assert: tile equals: (gameBoard at: 3 at: 2)! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:19'!
testPlaceTileAtBottomEdgeExtendsBoard
	 | tile |
	tile := KmTile blank.
	gameBoard at: 3 at: 2 put: tile.
	self assert: 4 equals: gameBoard rows.! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:20'!
testPlaceTileAtLeftEdgeExtendsBoard
	 | tile |
	tile := KmTile blank.
	gameBoard at: 2 at: 1 put: tile.
	self assert: 4 equals: gameBoard columns.! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:21'!
testPlaceTileAtLeftEdgeExtendsBoardAndRelocates
	 | tile |
	tile := KmTile blank.
	gameBoard at: 2 at: 1 put: tile.
	self assert: tile equals: (gameBoard at: 2 at: 2)! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:21'!
testPlaceTileAtRightEdgeExtendsBoard
	 | tile |
	tile := KmTile blank.
	gameBoard at: 3 at: 1 put: tile.
	self assert: 4 equals: gameBoard columns.! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:21'!
testPlaceTileAtTopEdgeExtendsBoard
	 | tile |
	tile := KmTile blank.
	gameBoard at: 1 at: 2 put: tile.
	self assert: 4 equals: gameBoard rows.! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:21'!
testPlaceTileAtTopEdgeExtendsBoardAndRelocates
	 | tile |
	tile := KmTile blank.
	gameBoard at: 1 at: 2 put: tile.
	self assert: tile equals: (gameBoard at: 2 at: 2)! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:21'!
testPlaceTileConnectsItToItsNeighbour
	 | tile |
	tile := KmTile blank.
	gameBoard at: 3 at: 2 put: tile.
	self assert: tile equals: ((gameBoard at: 2 at: 2) tileAt: Bottom)! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:18'!
testStartingTileAtCentre
	| board |
	board := gameBoard.
	self assert: board startingTile equals: (board at: 2 at: 2)! !

!KmTestGameBoard methodsFor: 'running' stamp: 'StuartHerring 5/14/2011 21:36'!
testSurroundingTilesAtStartIsEmpty
	self assert: (gameBoard surroundingTilesAt: 2 at: 2) isEmpty! !

!KmTestGameBoard methodsFor: 'running' stamp: 'StuartHerring 5/14/2011 21:41'!
testSurroundingTilesDontIncludeFurtherTiles
	| t t2 |
	t := KmTile buildFromString: 'FFFFFFFFF'.
	t2 := KmTile buildFromString: 'FFFFFFFFF'.
	gameBoard at: 1 at: 1 put: t.
	gameBoard at: 2 at: 1 put: t2.
	self assert: {t} equals: (gameBoard surroundingTilesAt: 3 at: 4) ! !

!KmTestGameBoard methodsFor: 'running' stamp: 'StuartHerring 5/14/2011 21:41'!
testSurroundingTilesWhenTilesPlaced
	| t |
	t := KmTile buildFromString: 'FFFFFFFFF'.
	gameBoard at: 1 at: 1 put: t.
	self assert: {t} equals: (gameBoard surroundingTilesAt: 3 at: 3) ! !

TestCase subclass: #KmTestGrid
	instanceVariableNames: 'fiveBySeven'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core-Support'!

!KmTestGrid methodsFor: 'running' stamp: 'StuartHerring 1/29/2011 12:42'!
setUp
	fiveBySeven := KmGrid ofSize: 5 by: 7.
	1 to: 5 do: [ :row |
		1 to: 7 do: [ : column | fiveBySeven at: row at: column put: row displayString, 'x', column displayString]] ! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/17/2011 11:22'!
testAddColumn
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	grid addColumn.
	self assert: 8 equals: grid columns.! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 12:35'!
testAddColumns
	| grid |
	grid := KmGrid new.
	grid addColumns: 7.
	self assert: 7 equals: grid columns.! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/17/2011 11:21'!
testAddRow
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	grid addRow.
	self assert: 6 equals: grid rows.! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 12:35'!
testAddRows
	| grid |
	grid := KmGrid new.
	grid addRows: 5.
	self assert: 5 equals: grid rows.! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/17/2011 19:57'!
testAdjacentItems
	self assert: ({'1x2'. '2x3'. '3x2'. '2x1' } hasEqualElements: (fiveBySeven adjacentItemsAt: 2 at: 2))! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 12:35'!
testEmptyGridColumns
	self assert: 0 equals: KmGrid new columns ! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 12:35'!
testEmptyGridRows
	self assert: 0 equals: KmGrid new rows! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 12:35'!
testInitialDataIsNil
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	self assert: nil equals: (grid at: 3 at: 4)! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 12:35'!
testInitialSizeColumns
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	self assert: 7 equals: grid columns.! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 12:35'!
testInitialSizeRows
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	self assert: 5 equals: grid rows.! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/17/2011 11:17'!
testPrependColumn
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	grid prependColumn.
	self assert: 8 equals: grid columns.! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/17/2011 11:14'!
testPrependColumnMovesItems
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	grid at: 2 at: 2 put: 'foo'.
	grid prependColumn.
	self assert: nil equals: (grid at: 2 at: 2).
	self assert: 'foo' equals: (grid at: 2 at: 3).! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/17/2011 11:16'!
testPrependRow
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	grid prependRow.
	self assert: 6 equals: grid rows.! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/17/2011 11:16'!
testPrependRowMovesItems
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	grid at: 2 at: 2 put: 'foo'.
	grid prependRow.
	self assert: nil equals: (grid at: 2 at: 2).
	self assert: 'foo' equals: (grid at: 3 at: 2).! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 12:35'!
testPutAndRetrieve
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	grid at: 3 at: 4 put: 'foo'.
	self assert: 'foo' equals: (grid at: 3 at: 4)! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 5/14/2011 21:25'!
testSurroundingItems
	self assert: {'1x1'. '1x2'. '1x3'. 
		'2x1'. '2x3'. 
		'3x1'. '3x2'. '3x3'.} 
	equals: (fiveBySeven surroundingItemsAt: 2 at: 2)! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 5/14/2011 21:28'!
testSurroundingItemsAtEdge
	self assert: {'1x1'. '1x2'. 
		'2x2'. 
		'3x1'. '3x2'.} 
	equals: (fiveBySeven surroundingItemsAt: 2 at: 1)! !

TestCase subclass: #KmTileSegmentTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/14/2011 10:47'!
testAdjacentSegmentsAcrossTilles
	|  t1 t2 |
	t1 := KmTile buildFromString: 'FFFFFFFFF'.
	t2:= KmTile buildFromString: 'FFFFFFFFF'.
	t1 tileAt: Top put: t2.
	self assert: {
		t2 at: Bottom.
		t1 at: TopRight. 
		t1 at: CentreTop. 
		t1 at: TopLeft} asSet equals: (t1 at: Top) adjacent 
! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/14/2011 10:48'!
testAdjacentSegmentsWithinTile
	|  t |
	t := KmTile buildFromString: 'FFFFFFFFF'.    
	self assert: {
		t at: CentreTop. 
		t at: CentreRight. 
		t at: CentreBottom. 
		t at: CentreLeft} asSet
	equals: (t at: Centre) adjacent! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:06'!
testBlockerSegmentCannotHavePiece
	self deny: KmNullTerritory newSegment canPlacePiece! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 19:57'!
testCompletingTerritoryCompletesSegment
	| tile1 tile2 |
	tile1 := KmTile buildFromString: 'FFFF-FFFF'.
	tile2 := KmTile buildFromString: 'FFFFFF-FF'.
	tile1 tileAt: Top put: tile2.
	self assert: (tile1 at: Top) isComplete.! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:03'!
testInitialSegmentCanHavePiece
	self assert: KmFarmTerritory newSegment canPlacePiece! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:09'!
testInitialSegmentHasNilPiece
	self assert: KmFarmTerritory newSegment piece isNil! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:09'!
testInitialSegmentHasNoPiece
	self deny: KmFarmTerritory newSegment hasPiece! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:05'!
testInitialSegmentIsIncomplete
	self deny: KmRoadTerritory newSegment isComplete! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:07'!
testNewSegmentIsIncomplete
	self deny: KmFarmTerritory newSegment isComplete! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:09'!
testPieceCanNotBePlacedIfSegmentsTerritoryAlreadyHasAPiece
	| s1 s2 |
	s1 := KmFarmTerritory newSegment.
	s2 := KmFarmTerritory newSegment.
	s1 territory mergeWith: s2 territory.
	s1 piece: KmPiece new.
	self deny: s2 canPlacePiece! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/12/2011 11:14'!
testPieceIsReturnedProperly
	| s p player |
	player := KmPlayer named: nil withColour: nil.
	s := KmFarmTerritory newSegment.
	p := player takePiece.
	s piece: p.
	s returnPiece.
	self assert: 5 equals: player pieces size.! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:09'!
testPlacingPieceWhenTerritoryAlreadyContainsAPieceThrowsError
	| s1 s2 |
	s1 := KmFarmTerritory newSegment.
	s2 := KmFarmTerritory newSegment.
	s1 territory mergeWith: s2 territory.
	s1 piece: KmPiece new.
	self should: [ s2 piece: KmPiece new ] raise: Error! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/12/2011 11:17'!
testReturnPieceRemovesPieceFromSegment
	| s p player |
	player := KmPlayer named: nil withColour: nil.
	s := KmFarmTerritory newSegment.
	p := player takePiece.
	s piece: p.
	s returnPiece.
	self deny: s hasPiece! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/12/2011 11:14'!
testReturnPieceWhenNoPieceSilentlyDoesNothing
	KmFarmTerritory newSegment returnPiece.! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:12'!
testRoadConnectsToRoad
	self assert: (KmRoadTerritory newSegment connectsTo: KmRoadTerritory newSegment)! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:12'!
testRoadDoesntConnectToBlocker
	self deny: (KmRoadTerritory newSegment connectsTo: KmNullTerritory newSegment)! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:12'!
testRoadSegmentTypeIsRoad
	self assert: #road equals: KmRoadTerritory newSegment type! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 19:57'!
testSegmentLocationAfterRotation
	| tile segment |
	tile := KmTile buildFromString: 'VFFFFFFFF'.
	segment := tile at: Top.
	tile rotate.
	self assert: Right equals: segment location.! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:03'!
testSegmentTypeIsTerritoryType
	| t s |
	s := KmFarmTerritory newSegment.
	t := s territory.
	self assert: t type equals: s type.! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:09'!
testSetPieceMeansSegmentHasPiece
	| s |
	s := KmFarmTerritory newSegment.
	s piece: KmPiece new.
	self assert: s hasPiece! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 16:19'!
testUnknownCodeThrowsError
	self should: [ KmTileSegment fromChar: $z in: nil ] raise: Error! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:10'!
testVillageConnectsToVillage
	self assert: (KmVillageTerritory newSegment connectsTo: KmVillageTerritory newSegment)! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:10'!
testVillageConnectsToWall
	self assert: (KmVillageTerritory newSegment connectsTo: KmVillageWallTerritory newSegment)! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:10'!
testVillageDoesntConnectToFarm
	self deny: (KmVillageTerritory newSegment connectsTo: KmFarmTerritory newSegment)! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:10'!
testVillageSegmentIsVillage
	self assert: KmVillageTerritory newSegment isVillage! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:10'!
testVillageSegmentTypeIsVillage
	self assert: #village equals: KmVillageTerritory newSegment type! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:10'!
testWallConnectsToVillage
	self assert: (KmVillageWallTerritory newSegment connectsTo: KmVillageTerritory newSegment)! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:10'!
testWallDoesntConnectToFarm
	self deny: (KmVillageWallTerritory newSegment connectsTo: KmFarmTerritory newSegment)! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:10'!
testWallDoesntConnectToWall
	self deny: (KmVillageWallTerritory newSegment connectsTo: KmVillageWallTerritory newSegment)! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:10'!
testWallSegmentIsVillage
	self assert: KmVillageWallTerritory newSegment isVillage! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 23:10'!
testWallSegmentTypeIsVillage
	self assert: #village equals: KmVillageWallTerritory newSegment type! !

TestCase subclass: #KmTileSetCreation
	instanceVariableNames: 'setName className'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmTileSetCreation class methodsFor: 'accessing' stamp: 'StuartHerring 5/9/2011 21:13'!
resources
	^{KmSuspendAutoTestResource}! !

!KmTileSetCreation methodsFor: 'running' stamp: 'StuartHerring 3/21/2011 22:17'!
setUp
	super setUp.
	className := #KmTSxxxTestxxx.
	setName := 'xxx Test xxx'.
	Smalltalk at: className ifPresent: [ :c | c removeFromSystem ].
! !

!KmTileSetCreation methodsFor: 'running' stamp: 'StuartHerring 3/21/2011 23:09'!
tearDown
	Smalltalk at: className ifPresent: [ :c | c removeFromSystem ].
! !

!KmTileSetCreation methodsFor: 'tests' stamp: 'StuartHerring 3/21/2011 21:09'!
testRegisterTileSetCreatesClass	
	KmTileSet register: setName asTileSetUsingStrings: {'FFFFFFFFF'}.
	self assert: (Smalltalk globals includesKey: className)! !

!KmTileSetCreation methodsFor: 'tests' stamp: 'StuartHerring 3/21/2011 21:10'!
testRegisterTileSetCreatesClassIsTileSet
	KmTileSet register: setName asTileSetUsingStrings: {'FFFFFFFFF'}.
	self assert: KmTileSet equals: (Smalltalk at: className) superclass ! !

!KmTileSetCreation methodsFor: 'tests' stamp: 'StuartHerring 3/21/2011 22:04'!
testRegisteredTileSetCanCreateTileSet
	| tileSet |
	KmTileSet register: setName asTileSetUsingStrings: #('FFFFFFFFF').
	tileSet := (Smalltalk at: className) new.
	self assert: 1 equals: tileSet size.! !

!KmTileSetCreation methodsFor: 'tests' stamp: 'StuartHerring 3/21/2011 22:54'!
testRegisteredTileSetHasCorrectName
	KmTileSet register: setName asTileSetUsingStrings: {'FFFFFFFFF'}.
	self assert: setName equals: (Smalltalk at: className) tilesetName! !

!KmTileSetCreation methodsFor: 'tests' stamp: 'StuartHerring 3/21/2011 22:54'!
testRegisteredTileSetInstanceHasCorrectName
	KmTileSet register: setName asTileSetUsingStrings: {'FFFFFFFFF'}.
	self assert: setName equals: (Smalltalk at: className) new name! !

TestCase subclass: #KmTileSetTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmTileSetTest methodsFor: 'tests' stamp: 'StuartHerring 3/21/2011 23:05'!
testBuildFromStrings
	| set |
	set := KmTileSet buildFromStrings: #('FFFFFFFFF' 'FFFFFFFFF' 'FFFFFFFFF').
	self assert: 3 equals: set size.! !

!KmTileSetTest methodsFor: 'tests' stamp: 'StuartHerring 3/21/2011 23:05'!
testStartingTileIsFirstInSet
	| set tile1 tile2 |
	tile1 := KmTile blank.
	tile2 := KmTile blank.
	set := KmTileSet buildFromTiles: { tile1. tile2 }.
	self assert: tile1 equals: set takeTile! !

!KmTileSetTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:36'!
testTakeTileReducesSize
	| set size |
	set := KmTileSet testSet.
	size := set size.
	set takeTile.
	self assert: size - 1 equals: set size.! !

!KmTileSetTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:44'!
testTakeTileRemovesItFromRemaining
	| set tile |
	set := KmTileSet testSet.
	tile := set takeTile.
	self deny: ((set instVarNamed: #tiles) includes: tile)! !

TestCase subclass: #KmTileTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmTileTest methodsFor: 'convenience' stamp: 'StuartHerring 1/28/2011 20:33'!
assertMappings: aCollection for: aTile
	self assert: (aCollection allSatisfy: [ :assoc | self verify: assoc key isNumber: assoc value inTile: aTile ]).! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 4/27/2011 18:21'!
testAdjacentVillagesInDifferentTerritories
	| tile |
	tile := KmTile buildFromString: 'WWFFVVFFFFFFF'.
	self deny: (tile at: Top) territory = (tile at: Right) territory.! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:03'!
testAllowsTile
	| tile1 |
	tile1 := KmTile startingTile.
	self assert: (tile1 allowsTile: KmTile blank at: Bottom)! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:03'!
testAllowsTileReturnsFalse
	| tile1 |
	tile1 := KmTile startingTile.
	self deny: (tile1 allowsTile: KmTile blank at: Top)! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:03'!
testAllowsTileReturnsFalseDueToPaths
	| tile1 |
	tile1 := KmTile startingTile.
	self deny: (tile1 allowsTile: KmTile blank at: Right)! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:03'!
testAllowsTileReturnsFalseWhenAlreadyOccupied
	| tile1 |
	tile1 := KmTile startingTile.
	tile1 tileAt: Bottom put: KmTile blank.
	self deny: (tile1 allowsTile: KmTile blank at: Bottom)! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 19:57'!
testBuildFromString
	| tile |
	tile := KmTile buildFromString: 'VFVFF-F--'.
	self assert: (tile at: TopLeft) isVillage.
	self assert: (tile at: TopRight) isVillage.
	self assert: (tile at: RightTop) isFarm.
	self assert: (tile at: RightBottom) isFarm.
	self assert: (tile at: BottomRight) isVillage.
	self assert: (tile at: BottomLeft) isVillage.
	self assert: (tile at: LeftBottom) isFarm.
	self assert: (tile at: LeftTop) isFarm.

	self assert: (tile at: Top) isFarm. 
	self assert: (tile at: Left) isRoad.
	self assert: (tile at: Bottom) isFarm.
	self assert: (tile at: Right) isRoad.
	self assert: (tile at: Centre) isRoad.! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 21:22'!
testBuildFromStringStopsAtPipe
	KmTile buildFromString: 'FFFFFFFFF|'.
	"Doesn't raise an error"
! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 5/11/2011 20:58'!
testCrossroadTerritories
	| tile1 |
	tile1 := KmTile buildFromString: 'FFFF----.'.
	self assert: 9 equals: tile1 territories size.! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 5/7/2011 21:02'!
testFarmWithAdjacentVillagesNotComplete
	| tile |
	tile := KmTile buildFromString: 'WWFFVVFFFFFFF'.
	self deny: (tile at: Bottom) territory isComplete ! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 4/21/2011 12:45'!
testInitialPaths
	| tile |
	tile := KmTile blank.
	self assertMappings: {
		Top -> 2.
		CentreTop -> 3.
		Right -> 6.
		CentreRight -> 7.
		Bottom -> 10.
		CentreBottom -> 11.
		Left -> 14.
		CentreLeft -> 15.
		Centre ->0 } for: tile.! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 4/21/2011 12:48'!
testInitialRegions
	| tile |
	tile := KmTile blank.
	self assertMappings: {
		TopLeft -> 1. TopRight -> 4.
		RightTop -> 5. RightBottom -> 8.
		BottomRight -> 9. BottomLeft ->12.
		LeftBottom -> 13. LeftTop -> 16} for: tile.! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:03'!
testNewTileHasNothingAdjacent
	 | tile |
	tile := KmTile blank.
	self assert: nil equals: (tile tileAt: Top).
	self assert: nil equals: (tile tileAt: Right).
	self assert: nil equals: (tile tileAt: Bottom).
	self assert: nil equals: (tile tileAt: Left)! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 4/27/2011 18:23'!
testNinePartStringSetsCentreLikeEdge
	| tile |
	tile := KmTile buildFromString: 'FFFF-FFFF'.
	self assert: (tile at: CentreTop) isRoad.
! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:03'!
testPlaceTile
	 | t1 t2 |
	t1 := KmTile blank.
	t2 := KmTile blank.
	
	t1 tileAt: Top put: t2.
	self assert: t2 equals: (t1 tileAt: Top)
! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:03'!
testPlaceTileSetsReciprocalTile
	 | t1 t2 |
	t1 := KmTile blank.
	t2 := KmTile blank.
	
	t1 tileAt: Top put: t2.
	self assert: t1 equals: (t2 tileAt: Bottom)
! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 3/6/2011 13:07'!
testPlacingTileMergesTerritories
	| tile1 tile2 |
	tile1 := KmTile blank.
	tile2 := KmTile blank.
	tile1 tileAt: Left put: tile2.
	self assert: tile1 territories equals: tile2 territories! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 4/21/2011 12:49'!
testRotatedPaths
	| tile |
	tile := KmTile blank.
	tile rotate.
	self assertMappings: {
		Top -> 14.
		CentreTop -> 15.
		Right -> 2.
		CentreRight -> 3.
		Bottom -> 6.
		CentreBottom -> 7.
		Left -> 10.
		CentreLeft -> 11.
		Centre ->0 } for: tile.! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 4/21/2011 12:59'!
testRotatedRegions
	| tile |
	tile := KmTile blank.
	tile rotate.
	self assertMappings: {
		TopLeft -> 13. TopRight -> 16.
		RightTop -> 1. RightBottom -> 4.
		BottomRight -> 5. BottomLeft ->8.
		LeftBottom -> 9. LeftTop -> 12} for: tile.! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:23'!
testSimpleTerritories
	| tile1 |
	tile1 := KmTile blank.
	self assert: 1 equals: tile1 territories size.! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 4/27/2011 18:23'!
testThirteenPartStringSetsCentreSeparately
	| tile |
	tile := KmTile buildFromString: 'FFFF-FFFFFFFF'.
	self assert: (tile at: CentreTop) isFarm.
! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 4/27/2011 20:01'!
testWallsOnDifferentTilesStillConnect
	| tile1 tile2 |
	tile1 := KmTile buildFromString: 'WFFFVFFFF'.
	tile2 := KmTile buildFromString: 'FFWFFFVFF'.
	self assert: (tile1 allowsTile: tile2 at: Top)! !

!KmTileTest methodsFor: 'convenience' stamp: 'StuartHerring 1/28/2011 20:34'!
verify: aSymbol isNumber: aNumber inTile: aTile
	^((aTile instVarNamed: #regions) at: aNumber) = (aTile at: aSymbol)! !

TestRunner subclass: #KmTestRunner
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Utilities'!

!KmTestRunner methodsFor: 'utilities' stamp: 'StuartHerring 2/13/2011 22:30'!
findCategories
	^Smalltalk organization categories select: [ :c | c beginsWith: 'Khami-Test'].! !

!KmTestRunner methodsFor: 'utilities' stamp: 'StuartHerring 2/13/2011 22:30'!
findClassesForCategories: aCollection
	| items |
	aCollection isEmpty
		ifTrue: [ ^ self findClassesForCategories: self findCategories ].
	items := aCollection
		gather: [ :category | 
			((Smalltalk organization listAtCategoryNamed: category) collect: [ :each | Smalltalk globals at: each ])
				select: [ :each | each includesBehavior: self baseClass ] ].
	^ items asSet! !

KmTileSet subclass: #KmTestingTileset
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmTestingTileset methodsFor: 'as yet unclassified' stamp: 'StuartHerring 5/12/2011 06:52'!
initializeWithTiles: aCollection
	self initialize.
	tiles := OrderedCollection new
		add: aCollection first;
		addAll: aCollection copyWithoutFirst;
		yourself! !

TestResource subclass: #KmSuspendAutoTestResource
	instanceVariableNames: 'autotestState'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Utilities'!

!KmSuspendAutoTestResource commentStamp: 'StuartHerring 5/9/2011 21:14' prior: 0!
TestCases that depend on this resource will prevent Autotest from running while they run.
This is useful for tests that perform any compilation activity which might confuse Autotest.!

!KmSuspendAutoTestResource methodsFor: 'running' stamp: 'StuartHerring 5/9/2011 21:23'!
setUp
	autotestState := (Smalltalk at: #AutotestListener 
		ifPresent: [ :c | c allInstances anySatisfy:  [ :l | 
				SystemChangeNotifier uniqueInstance hasNotificationsFor: l]]) 
		ifNil: [false].
	autotestState ifTrue: [ (Smalltalk at: #AutotestDashboard) close ]! !

!KmSuspendAutoTestResource methodsFor: 'running' stamp: 'StuartHerring 5/9/2011 21:26'!
tearDown
	autotestState ifTrue: [ (Smalltalk at: #AutotestDashboard) open ]! !
